@@ -214,7 +214,7 @@ source_is_browse_blacklisted (GrlSource *source)
 {
 	const char *id;
 	const char * const sources[] = {
-		/* https://bugzilla.gnome.org/show_bug.cgi?id=722422 */
+		/* https://gitlab.gnome.org/GNOME/grilo/issues/36 */
 		"grl-youtube",
 		NULL
 	};
@@ -682,8 +682,11 @@ browse_cb (GrlSource    *source,
 			GtkTreePath *path;
 
 			path = gtk_tree_row_reference_get_path (bud->ref_parent);
-			gtk_tree_model_get_iter (bud->model, &parent, path);
-			gtk_tree_path_free (path);
+			if (!path ||
+			    !gtk_tree_model_get_iter (bud->model, &parent, path)) {
+				g_clear_pointer (&path, gtk_tree_path_free);
+				return;
+			}
 
 			gtk_tree_model_get (bud->model, &parent,
 					    MODEL_RESULTS_REMAINING, &remaining_expected,
